lilypondproxytools.LilyPondGrobProxyContextWrapper
==================================================

.. abjad-lineage:: abjad.tools.lilypondproxytools.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper

.. autoclass:: abjad.tools.lilypondproxytools.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondproxytools.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper.__getattr__
      ~abjad.tools.lilypondproxytools.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper.__repr__

Bases
-----

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.lilypondproxytools.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper.__getattr__
   :noindex:

.. automethod:: abjad.tools.lilypondproxytools.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper.LilyPondGrobProxyContextWrapper.__repr__
   :noindex:
